[Zope3-checkins] CVS: Zope3/src/zope/app/component - hooks.py:1.15

Anthony Baxter anthony at interlink.com.au
Sun Feb 8 20:12:00 EST 2004


Update of /cvs-repository/Zope3/src/zope/app/component
In directory cvs.zope.org:/tmp/cvs-serv5648/src/zope/app/component

Modified Files:
	hooks.py 
Log Message:
service manager -> site manager


=== Zope3/src/zope/app/component/hooks.py 1.14 => 1.15 ===
--- Zope3/src/zope/app/component/hooks.py:1.14	Wed Dec 17 05:07:01 2003
+++ Zope3/src/zope/app/component/hooks.py	Sun Feb  8 20:11:59 2004
@@ -37,7 +37,7 @@
 
     clean_context = removeAllProxies(context)
 
-    # if the context is actually a service or service manager...
+    # if the context is actually a service or site manager...
     if IServiceService.isImplementedBy(clean_context):
         return trustedRemoveSecurityProxy(context)
 
@@ -51,13 +51,13 @@
                 # have a root object:
                 if not IContainmentRoot.isImplementedBy(context):
                     raise TypeError("Not enough context to get next "
-                                    "service manager")
+                                    "site manager")
 
             # Fall back to global:
             sm = serviceManager
         else:
             # We have a container, so context is a wrapper.  We still
             # don't have a service manager, so try again, recursively:
             sm = getServiceManager_hook(container, local, True)
 
     return sm
@@ -51,13 +51,13 @@
         else:
             # We have a container, so context is a wrapper.  We still
-            # don't have a service manager, so try again, recursively:
+            # don't have a site manager, so try again, recursively:
             sm = getServiceManager_hook(container, local, True)
 




More information about the Zope3-Checkins mailing list